@@ -40,15 +40,9 @@
  * This structure represents a PKCS11 CK_ATTRIBUTE. These attributes contain i
  * about a PKCS11 object. Use gck_object_get() or gck_object_set() to set and
  * attributes on an object.
- */
-
-/**
- * GckAttribute:
- * @type: The attribute type, such as CKA_LABEL.
- * @value: (array length=length): The value of the attribute. May be NULL.
- * @length: The length of the attribute. May be G_MAXULONG if the attribute is
  *
- * This structure represents a PKCS11 CK_ATTRIBUTE.
+ * Although you are free to allocate a #GckAttribute in your own code, no functions in
+ * this library will operate on such an attribute.
  */
 
 G_STATIC_ASSERT (sizeof (GckAttribute) == sizeof (CK_ATTRIBUTE));
@@ -129,12 +123,7 @@ value_ref (guchar *data)
 
 	g_assert (data != NULL);
 
-#if GLIB_CHECK_VERSION (2,29,90)
 	previous = g_atomic_int_add (value, 1);
-#else
-	previous = g_atomic_int_exchange_and_add (value, 1);
-#endif
-
 	if (G_UNLIKELY (previous <= 0)) {
 		g_warning ("An owned GckAttribute value has been modified outside of the "
 		           "gck library or an invalid attribute was passed to gck_builder_add_attribute()");
@@ -246,12 +235,7 @@ gck_builder_ref (GckBuilder *builder)
 
 	g_return_val_if_fail (builder != NULL, NULL);
 
-#if GLIB_CHECK_VERSION (2,29,90)
 	stack = g_atomic_int_add (&real->refs, 1) == 0;
-#else
-	stack = g_atomic_int_exchange_and_add (&real->refs, 1) == 0;
-#endif
-
 	if G_UNLIKELY (stack) {
 		g_warning ("Never call gck_builder_ref() on a stack allocated GckBuilder structure");
 		return NULL;
@@ -1394,19 +1378,6 @@ gck_builder_clear (GckBuilder *builder)
 	real->array = NULL;
 }
 
-/**
- * SECTION:gck-attribute
- * @title: GckAttribute
- * @short_description: A PKCS11 attribute.
- *
- * This structure represents a PKCS11 CK_ATTRIBUTE. These attributes contain information
- * about a PKCS11 object. Use gck_object_get() or gck_object_set() to set and retrieve
- * attributes on an object.
- *
- * Although you are free to allocate a #GckAttribute in your own code, no functions in
- * this library will operate on such an attribute.
- */
-
 /**
  * GckAttribute:
  * @type: The attribute type, such as CKA_LABEL.
