@@ -28,11 +28,11 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include "pkcs11.h"
+#include <p11-kit/pkcs11.h>
 
 #define __GCK_INSIDE_HEADER__
 
-#include "gck-enum-types.h"
+#include <gck/gck-enum-types.h>
 
 G_BEGIN_DECLS
 
@@ -252,9 +252,6 @@ void                 gck_builder_add_string                 (GckBuilder *builder
 void                 gck_builder_add_attribute              (GckBuilder *builder,
                                                              const GckAttribute *attr);
 
-void                 gck_builder_add_owned                  (GckBuilder *builder,
-                                                             const GckAttribute *attr);
-
 void                 gck_builder_add_all                    (GckBuilder *builder,
                                                              GckAttributes *attrs);
 
