@@ -382,11 +382,7 @@ gcr_system_prompt_constructed (GObject *obj)
 
 	G_OBJECT_CLASS (gcr_system_prompt_parent_class)->constructed (obj);
 
-#if GLIB_CHECK_VERSION (2,29,90)
 	seed = g_atomic_int_add (&unique_prompt_id, 1);
-#else
-	seed = g_atomic_int_exchange_and_add (&unique_prompt_id, 1);
-#endif
 
 	self->pv->prompt_path = g_strdup_printf ("%s/p%d", GCR_DBUS_PROMPT_OBJECT_PREFIX, seed);
 
@@ -437,7 +433,7 @@ gcr_system_prompt_class_init (GcrSystemPromptClass *klass)
 	g_type_class_add_private (gobject_class, sizeof (GcrSystemPromptPrivate));
 
 	/**
-	 * GcrSystemPrompt:bus-name
+	 * GcrSystemPrompt:bus-name:
 	 *
 	 * The DBus bus name of the prompter to use for prompting, or %NULL
 	 * for the default prompter.
@@ -447,7 +443,7 @@ gcr_system_prompt_class_init (GcrSystemPromptClass *klass)
 	                                 NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
 	/**
-	 * GcrSystemPrompt:timeout-seconds
+	 * GcrSystemPrompt:timeout-seconds:
 	 *
 	 * The timeout in seconds to wait when opening the prompt.
 	 */
@@ -456,7 +452,7 @@ gcr_system_prompt_class_init (GcrSystemPromptClass *klass)
 	                                 -1, G_MAXINT, -1, G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 
 	/**
-	 * GcrSystemPrompt:secret-exchange
+	 * GcrSystemPrompt:secret-exchange:
 	 *
 	 * The #GcrSecretExchange to use when transferring passwords. A default
 	 * secret exchange will be used if this is not set.
